/*
 *                 IFS Research & Development
 *
 *  This program is protected by copyright law and by international
 *  conventions. All licensing, renting, lending or copying (including
 *  for private use), and all other use of the program, which is not
 *  expressively permitted by IFS Research & Development (IFS), is a
 *  violation of the rights of IFS. Such violations will be reported to the
 *  appropriate authorities.
 *
 *  VIOLATIONS OF ANY COPYRIGHT IS PUNISHABLE BY LAW AND CAN LEAD
 *  TO UP TO TWO YEARS OF IMPRISONMENT AND LIABILITY TO PAY DAMAGES.
 * ----------------------------------------------------------------------------
 * File        : MyListConnectReaderConfig.java
 * Description :
 * Notes       :
 * ----------------------------------------------------------------------------
 * Modified    :
 *    2016-Feb-18  Jacek P  Created.
 * ----------------------------------------------------------------------------
 */

package ifs.fndint.connectreader;

import ifs.fnd.base.IfsException;
import ifs.application.fndconnectframework.ConfigParameter;
import ifs.fnd.connect.config.Config;
import ifs.fnd.connect.config.ConnectorReadersConfig;

/**
 * Class defining configuration parameters for custom Connect Reader.
 * Parameters are read during system initialization and stored as read-only
 * (final) variables in the class for simple access. Therefore reading of
 * parameters is done by the inner Builder class.
 * @author japase
 */
public class MyListConnectReaderConfig extends ConnectorReadersConfig {

   //==========================================================================
   //   Inner Builder class
   //==========================================================================

   static class Builder extends ConnectorReadersConfig.Builder {

      private String inDir = null;

      @Override
      protected void init(String name, ConfigParameter param) throws IfsException {
         switch (name) {
            // read all reader specific parameters
            // Common parameters: FACTORY_CLASS, EXECUTION_MODE, CREATE_RESPONSE,
            // LOG_LEVEL, MAX_RETRIES, MESSAGE_SELECTOR, DEFAULT_ENCODING,
            // WORK_TIMEOUT and ENABLED
            // are handled by the framework and don't need to be read here
            case "IN_DIRECTORY":
               inDir = replacePlaceholders(getTextValue(name,param));
               // location parameter defined in the super class is used during routing.
               // Each reader decides meaning of this parameter.
               location = inDir;
               break;
         }
      }

      @Override
      protected void postInit() throws IfsException {
         // any code that has to be executed after all parameters have been read,
         // e.g. parameter validation, consistency, variables that depend on several parameters, etc...
      }

      @Override
      protected Config newConfig() {
         return new MyListConnectReaderConfig(this);
      }
   }

   //==========================================================================
   //   Config instance
   //==========================================================================

   // Reader specific config parameters as public final variables - have to be reread on config change
   // Following parameters common to all senders are handled by the superclasses
   // and ara available as public final variables:
   // instance, type, executionMode, createResponse, logLevel, maxRetries,
   // messageSelector, defEncoding, location, workTimeout

   public final String  inDir;

   private MyListConnectReaderConfig(Builder builder) {
      super(builder);
      inDir = builder.inDir;
   }

   @Override
   public String toString() {
      return "MyListConnectReaderConfig{" + "inDir=" + inDir + '}'
             + " + " + super.toString();
   }
}
